==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControlUI/src/com/clustercontrol/composite/NumberVerifyListener.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.composite;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.VerifyEvent;
import org.eclipse.swt.events.VerifyListener;
import org.eclipse.swt.widgets.Text;

/**
 * VerifyListener饹
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class NumberVerifyListener implements VerifyListener {
    protected static String numberChar = "0123456789-";

    protected static String minusChar = "-";

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.swt.events.VerifyListener#verifyText(org.eclipse.swt.events.VerifyEvent)
     */
    public void verifyText(VerifyEvent e) {
        //ϰʳͭˤ
        if (e.keyCode == 0) {
            return;
        }
        //BackspaceDelete줿Ȥϡͭˤ
        if (e.character == SWT.BS || e.character == SWT.DEL) {
            return;
        }
        //'-'ʳ̵ˤ
        if (numberChar.indexOf(Character.toString(e.character)) == -1) {
            e.doit = false;
        }
        //'-'ξϤǤ˿ϤƤ̵ˤ
        if (minusChar.indexOf(Character.toString(e.character)) == 0) {
            Text text = (Text) e.getSource();
            if (text.getText().length() > 0) {
                e.doit = false;
            }
        }
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControlUI/src/com/clustercontrol/composite/NumberVerifyListener.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.composite;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.VerifyEvent;
import org.eclipse.swt.events.VerifyListener;
import org.eclipse.swt.widgets.Text;

/**
 * 数値用VerifyListenerクラス
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class NumberVerifyListener implements VerifyListener {
    protected static String numberChar = "0123456789-";

    protected static String minusChar = "-";

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.swt.events.VerifyListener#verifyText(org.eclipse.swt.events.VerifyEvent)
     */
    public void verifyText(VerifyEvent e) {
        //キー入力以外は有効にする
        if (e.keyCode == 0) {
            return;
        }
        //BackspaceやDeleteが押されたときは、有効にする
        if (e.character == SWT.BS || e.character == SWT.DEL) {
            return;
        }
        //数字と'-'以外は無効にする
        if (numberChar.indexOf(Character.toString(e.character)) == -1) {
            e.doit = false;
        }
        //'-'の場合はすでに数字が入力されていたら無効にする
        if (minusChar.indexOf(Character.toString(e.character)) == 0) {
            Text text = (Text) e.getSource();
            if (text.getText().length() > 0) {
                e.doit = false;
            }
        }
    }
}
